==> nextcloud-22.2.5.tar.bz2: nextcloud/apps/serverinfo/l10n/hr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Podaci o CPU-u nisu dostupni",
    "Users" : "Korisnici",
    "Groups" : "Grupe",
    "Links" : "Poveznice",
    "Federated sent" : "Udruženo poslano",
    "Federated received" : "Udruženo primljeno",
    "Talk conversations" : "Razgovori u alatu Talk",
    "24 hours" : "24 sata",
    "1 hour" : "1 sat",
    "5 mins" : "5 min",
    "Copy" : "Kopiraj",
    "Copied!" : "Kopirano!",
    "Not supported!" : "Nije podržano!",
    "Press ⌘-C to copy." : "Pritisnite ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
    "System" : "Sustav",
    "Monitoring" : "Praćenje",
    "Monitoring app with useful server information" : "Aplikacija za praćenje s korisnim informacijama o poslužitelju",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Pruža korisne informacije o poslužitelju, kao što su opterećenje CPU-a, korištenje RAM-a, korištenje diska, broj korisnika itd.",
    "Operating System" : "Operacijski sustav",
    "CPU" : "CPU",
    "Memory" : "Memorija",
    "Server time" : "Vrijeme poslužitelja",
    "Uptime" : "Radno vrijeme",
    "Load" : "Opterećenje",
    "Disk" : "Disk",
    "Mount" : "Postavljanje",
    "Filesystem" : "Datotečni sustav",
    "Size" : "Veličina",
    "Available" : "Dostupno",
    "Used" : "Iskorišteno",
    "You will get a notification once one of your disks is nearly full." : "Primit ćete obavijest kada je jedan od vaših diskova skoro pun.",
    "Network" : "Mreža",
    "Hostname" : "Naziv poslužitelja",
    "DNS" : "DNS",
    "Gateway" : "Pristupni poslužitelj",
    "Status" : "Status",
    "Speed" : "Brzina",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Aktivni korisnici",
    "Shares" : "Dijeljenja",
    "PHP" : "PHP",
    "Database" : "Baza podataka",
    "External monitoring tool" : "Vanjski alat za praćenje",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Dodavanjem „?format = json” na kraj URL-a dobije se rezultat u JSON-u.",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Zatim proslijedite token sa zaglavljem „NC-Token“ prilikom slanja upita za gornji URL.",
    "Load average" : "Prosječno opterećenje",
    "Last minute" : "Zadnja minuta",
    "Memory info not available" : "Podaci o memoriji nisu dostupni",
    "Total" : "Ukupno",
    "Current usage" : "Trenutno opterećenje",
    "Mails" : "Pošta",
    "Files:" : "Datoteke:",
    "Storages:" : "Pohrane:",
    "Free Space:" : "Slobodan prostor:",
    "Total users:" : "Ukupno korisnika:",
    "Version:" : "Inačica:",
    "Memory Limit:" : "Ograničenje memorije:",
    "Max Execution Time:" : "Maksimalno vrijeme izvršenja:",
    "Upload max size:" : "Maksimalna veličina za otpremu:",
    "Type:" : "Vrsta:",
    "Size:" : "Veličina:",
    "You can connect an external monitoring tool by using this end point:" : "Možete povezati vanjski alat za praćenje s pomoću ove krajnje točke:"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-31.0.10.tar.bz2: nextcloud/apps/serverinfo/l10n/hr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Podaci o CPU-u nisu dostupni",
    "Copied!" : "Kopirano!",
    "Not supported!" : "Nije podržano!",
    "Press ⌘-C to copy." : "Pritisnite ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
    "System" : "Sustav",
    "Monitoring" : "Praćenje",
    "Monitoring app with useful server information" : "Aplikacija za praćenje s korisnim informacijama o poslužitelju",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Pruža korisne informacije o poslužitelju, kao što su opterećenje CPU-a, korištenje RAM-a, korištenje diska, broj korisnika itd.",
    "Temperature" : "Temperatura",
    "Load" : "Opterećenje",
    "Memory" : "Memorija",
    "Disk" : "Disk",
    "Size:" : "Veličina:",
    "Files:" : "Datoteke:",
    "Storages:" : "Pohrane:",
    "Free Space:" : "Slobodan prostor:",
    "Network" : "Mreža",
    "Active users" : "Aktivni korisnici",
    "Last hour" : "Posljednji sat",
    "Shares" : "Dijeljenja",
    "Users:" : "Korisnici:",
    "PHP" : "PHP",
    "Version:" : "Inačica:",
    "Upload max size:" : "Maksimalna veličina za otpremu:",
    "Database" : "Baza podataka",
    "Type:" : "Vrsta:",
    "External monitoring tool" : "Vanjski alat za praćenje",
    "Copy" : "Kopiraj",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Zatim proslijedite token sa zaglavljem „NC-Token“ prilikom slanja upita za gornji URL."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
